==> xmule-1.8.4.tar.bz2: xmule-1.8.4/src/wintypes.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef _WINTYPES_H
#define _WINTYPES_H

typedef unsigned int UINT;
typedef UINT* UINT_PTR;

typedef char* LPCSTR;
typedef unsigned char BYTE;
typedef unsigned long DWORD;
typedef unsigned long BOOL;
typedef signed long LONG;
typedef unsigned long ULONG;
typedef unsigned long long ULONGLONG;
typedef BYTE* LPBYTE;
typedef int INT;
typedef unsigned short WORD;
typedef unsigned char* LPCTSTR;
typedef DWORD COLORREF;
typedef void VOID;
typedef void* LPVOID;
typedef void* PVOID;

typedef struct _POINT {
  UINT x,y;
} POINT;

typedef struct _RECT {
  UINT left,top,right,bottom;
} RECT;

typedef RECT* LPRECT;

typedef struct _WINDOWPLACEMENT {
    UINT length;
    UINT flags;
    UINT showCmd;
    POINT ptMinPosition;
    POINT ptMaxPosition;
    RECT rcNormalPosition;
} WINDOWPLACEMENT;

#endif

==> xmule-1.9.0.tar.bz2: xmule-1.9.0/src/wintypes.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef _WINTYPES_H
#define _WINTYPES_H

#include <stdint.h>                         // Needed for uint64_t

typedef unsigned int UINT;
typedef UINT* UINT_PTR;

typedef char* LPCSTR;
typedef unsigned char BYTE;
typedef unsigned long DWORD;
typedef unsigned long BOOL;
typedef signed long LONG;
typedef unsigned long ULONG;
typedef uint64_t ULONGLONG;
typedef BYTE* LPBYTE;
typedef int INT;
typedef unsigned short WORD;
typedef unsigned char* LPCTSTR;
typedef DWORD COLORREF;
typedef void VOID;
typedef void* LPVOID;
typedef void* PVOID;

typedef struct _POINT {
  UINT x,y;
} POINT;

typedef struct _RECT {
  UINT left,top,right,bottom;
} RECT;

typedef RECT* LPRECT;

typedef struct _WINDOWPLACEMENT {
    UINT length;
    UINT flags;
    UINT showCmd;
    POINT ptMinPosition;
    POINT ptMaxPosition;
    RECT rcNormalPosition;
} WINDOWPLACEMENT;

#endif
